=== modified file 'loggerhead/apps/branch.py'
--- loggerhead/apps/branch.py	2008-10-24 02:26:05 +0000
+++ loggerhead/apps/branch.py	2008-12-05 18:52:44 +0000
@@ -110,7 +110,7 @@
         self.branch.lock_read()
         try:
             try:
-                c = cls(self, self.get_history())
+                c = cls(self, self.get_history)
                 return c(environ, start_response)
             except:
                 environ['exc_info'] = sys.exc_info()

=== modified file 'loggerhead/controllers/__init__.py'
--- loggerhead/controllers/__init__.py	2008-10-25 19:26:49 +0000
+++ loggerhead/controllers/__init__.py	2008-12-05 18:52:44 +0000
@@ -58,14 +58,21 @@
 
     template_path = None
 
-    def __init__(self, branch, history):
+    def __init__(self, branch, history_callable):
         self._branch = branch
-        self._history = history
+        self._history_callable = history_callable
+        self.__history = None
         self.log = branch.log
 
+    @property
+    def _history(self):
+        if self.__history is not None:
+            return self.__history
+        self.__history = self._history_callable()
+        return self.__history
+
     def __call__(self, environ, start_response):
         z = time.time()
-        h = self._history
         kwargs = dict(parse_querystring(environ))
         util.set_context(kwargs)
         args = []
@@ -75,27 +82,21 @@
                 break
             args.append(arg)
 
-        revid = None
-        if h is not None:
-            if len(args) > 0:
-                revid = h.fix_revid(args[0])
-            else:
-                revid = h.last_revid
-
         path = None
         if len(args) > 1:
             path = '/'.join(args[1:])
+        self.args = args
 
         vals = {
             'static_url': self._branch.static_url,
             'branch': self._branch,
             'util': util,
-            'history': h,
             'url': self._branch.context_url,
         }
         vals.update(templatefunctions)
         headers = {}
-        vals.update(self.get_values(h, revid, path, kwargs, headers))
+
+        vals.update(self.get_values(path, kwargs, headers))
 
         self.log.info('Getting information for %s: %r secs' % (
             self.__class__.__name__, time.time() - z))
@@ -115,3 +116,12 @@
                 w.bytes_saved,
                 100.0*w.bytes_saved/w.bytes))
         return []
+
+    def get_revid(self):
+        h = self._history
+        if h is None:
+            return None
+        if len(self.args) > 0:
+            return h.fix_revid(args[0])
+        else:
+            return h.last_revid

=== modified file 'loggerhead/controllers/annotate_ui.py'
--- loggerhead/controllers/annotate_ui.py	2008-11-18 08:36:47 +0000
+++ loggerhead/controllers/annotate_ui.py	2008-12-05 18:52:44 +0000
@@ -37,8 +37,9 @@
 
     template_path = 'loggerhead.templates.annotate'
 
-    def get_values(self, history, revid, path, kwargs, headers):
-
+    def get_values(self, path, kwargs, headers):
+        history = self._history
+        revid = self.get_revid()
         revid = history.fix_revid(revid)
         file_id = kwargs.get('file_id', None)
         if (file_id is None) and (path is None):
@@ -89,4 +90,5 @@
             'fileview_active': True,
             'directory_breadcrumbs': directory_breadcrumbs,
             'branch_breadcrumbs': branch_breadcrumbs,
+            'history': self._history,
         }

=== modified file 'loggerhead/controllers/atom_ui.py'
--- loggerhead/controllers/atom_ui.py	2008-10-25 19:19:05 +0000
+++ loggerhead/controllers/atom_ui.py	2008-12-05 18:52:44 +0000
@@ -24,7 +24,9 @@
 
     template_path = 'loggerhead.templates.atom'
 
-    def get_values(self, history, revid, path, kwargs, headers):
+    def get_values(self, path, kwargs, headers):
+        history = self._history
+        revid = self.get_revid()
         pagesize = int(20)#self._branch.config.get('pagesize', '20'))
 
         revid_list = history.get_file_view(history.last_revid, None)
@@ -34,4 +36,5 @@
         return {
             'changes': entries,
             'updated': entries[0].date.isoformat() + 'Z',
+            'history': self._history,
         }

=== modified file 'loggerhead/controllers/changelog_ui.py'
--- loggerhead/controllers/changelog_ui.py	2008-10-25 19:26:49 +0000
+++ loggerhead/controllers/changelog_ui.py	2008-12-05 18:52:44 +0000
@@ -27,8 +27,9 @@
 
     template_path = 'loggerhead.templates.changelog'
 
-    def get_values(self, history, revid, path, kwargs, headers):
-
+    def get_values(self, path, kwargs, headers):
+        history = self._history
+        revid = self.get_revid()
         filter_file_id = kwargs.get('filter_file_id', None)
         query = kwargs.get('q', None)
         start_revid = history.fix_revid(kwargs.get('start_revid', None))

=== modified file 'loggerhead/controllers/diff_ui.py'
--- loggerhead/controllers/diff_ui.py	2008-11-07 14:20:51 +0000
+++ loggerhead/controllers/diff_ui.py	2008-12-05 18:52:44 +0000
@@ -24,18 +24,14 @@
 
 from bzrlib.diff import show_diff_trees
 
+from loggerhead.controllers import TemplatedBranchView
 
 log = logging.getLogger("loggerhead.controllers")
 
 
-class DiffUI(object):
+class DiffUI(TemplatedBranchView):
     """Class to output a diff for a single file or revisions."""
 
-    def __init__(self, branch, history):
-        self._branch = branch
-        self._history = history
-        self.log = history.log
-
     def __call__(self, environ, start_response):
         # /diff/<rev_id>/<rev_id>
         """Default method called from /diff URL."""

=== modified file 'loggerhead/controllers/directory_ui.py'
--- loggerhead/controllers/directory_ui.py	2008-10-25 19:26:49 +0000
+++ loggerhead/controllers/directory_ui.py	2008-12-05 18:52:44 +0000
@@ -57,13 +57,13 @@
             def static_url(path):
                 return self._static_url_base + path
         self._branch = _branch
-        self._history = None
+        self._history_callable = lambda:None
         self._path = path
         self._name = name
         self._static_url_base = static_url_base
         self.log = logging.getLogger('')
 
-    def get_values(self, h, revid, path, kwargs, response):
+    def get_values(self, path, kwargs, response):
         listing = [d for d in os.listdir(self._path)
                    if not d.startswith('.')
                    and os.path.isdir(os.path.join(self._path, d))]

=== modified file 'loggerhead/controllers/download_ui.py'
--- loggerhead/controllers/download_ui.py	2008-10-24 02:26:05 +0000
+++ loggerhead/controllers/download_ui.py	2008-12-05 18:52:44 +0000
@@ -24,15 +24,12 @@
 from paste import httpexceptions
 from paste.request import path_info_pop
 
+from loggerhead.controllers import TemplatedBranchView
+
 log = logging.getLogger("loggerhead.controllers")
 
 
-class DownloadUI (object):
-
-    def __init__(self, branch, history):
-        self._branch = branch
-        self._history = history
-        self.log = branch.log
+class DownloadUI (TemplatedBranchView):
 
     def __call__(self, environ, start_response):
         # /download/<rev_id>/<file_id>/[filename]

=== modified file 'loggerhead/controllers/error_ui.py'
--- loggerhead/controllers/error_ui.py	2008-12-05 05:14:01 +0000
+++ loggerhead/controllers/error_ui.py	2008-12-05 18:52:44 +0000
@@ -28,10 +28,10 @@
     template_path = 'loggerhead.templates.error'
 
     def __init__(self, branch, exc_info):
-        super(ErrorUI, self).__init__(branch, None)
+        super(ErrorUI, self).__init__(branch, lambda:None)
         self.exc_info = exc_info
 
-    def get_values(self, h, revid, path, kwargs, response):
+    def get_values(self, path, kwargs, response):
         exc_type, exc_object, exc_tb = self.exc_info
         description = StringIO()
         traceback.print_exception(exc_type, exc_object, None, file=description)

=== modified file 'loggerhead/controllers/inventory_ui.py'
--- loggerhead/controllers/inventory_ui.py	2008-11-14 06:58:10 +0000
+++ loggerhead/controllers/inventory_ui.py	2008-12-05 18:52:44 +0000
@@ -45,7 +45,9 @@
 
     template_path = 'loggerhead.templates.inventory'
 
-    def get_values(self, history, revid, path, kwargs, headers):
+    def get_values(self, path, kwargs, headers):
+        history = self._history
+        revid = self.get_revid()
 
         try:
             inv = history.get_inventory(revid)

=== modified file 'loggerhead/controllers/revision_ui.py'
--- loggerhead/controllers/revision_ui.py	2008-10-25 19:26:49 +0000
+++ loggerhead/controllers/revision_ui.py	2008-12-05 18:52:44 +0000
@@ -30,7 +30,9 @@
 
     template_path = 'loggerhead.templates.revision'
 
-    def get_values(self, h, revid, path, kwargs, headers):
+    def get_values(self, path, kwargs, headers):
+        h = self._history
+        revid = self.get_revid()
 
         filter_file_id = kwargs.get('filter_file_id', None)
         start_revid = h.fix_revid(kwargs.get('start_revid', None))

=== modified file 'loggerhead/controllers/search_ui.py'
--- loggerhead/controllers/search_ui.py	2008-10-25 19:26:49 +0000
+++ loggerhead/controllers/search_ui.py	2008-12-05 18:52:44 +0000
@@ -28,7 +28,7 @@
 
     template_path = 'loggerhead.templates.search'
 
-    def get_values(self, history, revid, path, kwargs, response):
+    def get_values(self, path, kwargs, response):
         """
         Default method called from the search box as /search URL
 
@@ -38,7 +38,7 @@
         terms = []
         query = kwargs['query']
         if len(query) > 0:
-            terms = search.search_revisions(history._branch, query, True)
+            terms = search.search_revisions(self._branch.branch, query, True)
             if terms is not None:
                 terms = [term[0] for term in terms]
             else:

